@@ -8,6 +8,14 @@ use Config ();
 use Cwd ();
 use File::Spec ();
 
+use Exporter ();
+@ISA = 'Exporter';
+
+@EXPORT_OK = qw( inc_dirs lib_dirs );
+%EXPORT_TAGS = (
+    all => \ @EXPORT_OK,
+);
+
 sub unique {
     my %seen;
     return
@@ -17,7 +25,6 @@ sub unique {
 
 sub inc_dirs {
     return
-        grep { defined() && length() && -d }
         unique(
             Cwd::getcwd(),
             map { File::Spec->catdir( $_, 'Alien', 'Judy' ) }
@@ -28,7 +35,6 @@ sub inc_dirs {
 
 sub lib_dirs {
     return
-        grep { defined() && length() && -d }
         unique(
             map { File::Spec->catdir( $_, 'Alien', 'Judy' ) }
             grep { defined() && length() }
@@ -36,6 +42,6 @@ sub lib_dirs {
         );
 }
 
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 1;
